==> piwigo-2.1.6.zip: piwigo/plugins/LocalFilesEditor/language/sr_RS/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf']    = 'Лична подешавања';
$lang['locfiledit_onglet_css']          = 'css датотека';
$lang['locfiledit_onglet_tpl']          = 'Шаблон';
$lang['locfiledit_onglet_lang']         = 'Језици';
$lang['locfiledit_onglet_plug']         = 'Лични додатак';
$lang['locfiledit_cant_save']           = 'Тренутна датотека није записана. Проверите да ли је директоријум "local/" има дозволу за упис  (chmod).';
$lang['locfiledit_newfile']             = 'Датотека не постоји и биће направљена програмом LocalFiles Editor';
$lang['locfiledit_save_config']         = 'Датотека је успешно записана.';
$lang['locfiledit_show_default']        = 'Прикажи подразумевану датотеку: ';
$lang['locfiledit_save_bak']            = 'Резервна копија ће бити направљена приликом снимања.';
$lang['locfiledit_saved_bak']           = 'Резервна копија је направљена (%s)';
$lang['locfiledit_save_file']           = 'Запамти датотеку';
$lang['locfiledit_choose_file']         = 'Изабери датотеку за уређивање';
$lang['locfiledit_edit']                = 'Измени';
$lang['locfiledit_restore']             = 'Обнови резервну копију датотеке';
$lang['locfiledit_restore_confirm']     = 'Молимо Вас да потврдите? Обнављање ће бити важеће после снимања.';
$lang['locfiledit_bak_loaded1']         = 'Резервна копија је учитана.';
$lang['locfiledit_bak_loaded2']         = 'Морате да запамтите датотеку пре обнављања.';
$lang['locfiledit_syntax_error']        = 'Синтаксна грешка! Датотека не може бити снимљена.';
$lang['locfiledit_enable_editarea']     = 'Омогући област промене';
$lang['locfiledit_disable_editarea']    = 'Онемогући област промене';
$lang['locfiledit_new_tpl']             = 'Направи нову датотеку';
$lang['locfiledit_new_filename']        = 'Име датотеке';
$lang['locfiledit_model']               = 'Модел';
$lang['locfiledit_empty_page']          = 'Празна страница';
$lang['locfiledit_parent_directory']    = 'Надређени директоријум';
$lang['locfiledit_filename_error']      = 'Забрањени знаци у називу датотеке.';
$lang['locfiledit_file_already_exists'] = 'Датотека већ постоји.';
$lang['locfiledit_model_error']         = 'Морате изабрати модел.';
$lang['locfiledit_empty_filename']      = 'Морате уписати име датотеке.';
$lang['locfiledit_webmaster_only']      = 'Само уредник интернет страница може да направи или уреди локалне датотеке.';

?>

==> piwigo-2.3.4.zip: piwigo/plugins/LocalFilesEditor/language/sr_RS/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf']    = 'Лична подешавања';
$lang['locfiledit_onglet_css']          = 'css датотека';
$lang['locfiledit_onglet_tpl']          = 'Шаблон';
$lang['locfiledit_onglet_lang']         = 'Језици';
$lang['locfiledit_onglet_plug']         = 'Лични додатак';
$lang['locfiledit_cant_save']           = 'Тренутна датотека није записана. Проверите да ли је директоријум "local/" има дозволу за упис  (chmod).';
$lang['locfiledit_newfile']             = 'Датотека не постоји и биће направљена програмом LocalFiles Editor';
$lang['locfiledit_save_config']         = 'Датотека је успешно записана.';
$lang['locfiledit_show_default']        = 'Прикажи подразумевану датотеку: ';
$lang['locfiledit_save_bak']            = 'Резервна копија ће бити направљена приликом снимања.';
$lang['locfiledit_saved_bak']           = 'Резервна копија је направљена (%s)';
$lang['locfiledit_save_file']           = 'Запамти датотеку';
$lang['locfiledit_choose_file']         = 'Изабери датотеку за уређивање';
$lang['locfiledit_edit']                = 'Измени';
$lang['locfiledit_restore']             = 'Обнови резервну копију датотеке';
$lang['locfiledit_restore_confirm']     = 'Молимо Вас да потврдите? Обнављање ће бити важеће после снимања.';
$lang['locfiledit_bak_loaded1']         = 'Резервна копија је учитана.';
$lang['locfiledit_bak_loaded2']         = 'Морате да запамтите датотеку пре обнављања.';
$lang['locfiledit_syntax_error']        = 'Синтаксна грешка! Датотека не може бити снимљена.';
$lang['locfiledit_new_tpl']             = 'Направи нову датотеку';
$lang['locfiledit_new_filename']        = 'Име датотеке';
$lang['locfiledit_model']               = 'Модел';
$lang['locfiledit_empty_page']          = 'Празна страница';
$lang['locfiledit_parent_directory']    = 'Надређени директоријум';
$lang['locfiledit_filename_error']      = 'Забрањени знаци у називу датотеке.';
$lang['locfiledit_file_already_exists'] = 'Датотека већ постоји.';
$lang['locfiledit_model_error']         = 'Морате изабрати модел.';
$lang['locfiledit_empty_filename']      = 'Морате уписати име датотеке.';
$lang['locfiledit_webmaster_only']      = 'Само уредник интернет страница може да направи или уреди локалне датотеке.';
?>
